@@ -1,7 +1,7 @@
 package App::hr;
 
-our $DATE = '2015-12-28'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-06-17'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use feature 'say';
 use strict 'subs', 'vars';
@@ -11,22 +11,17 @@ use Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(
                        hr
+                       hr_r
                );
 
 our %SPEC;
 
-# IFBUILT
+# from Code::Embeddable
 sub pick {
     return undef unless @_;
     return $_[@_*rand];
 }
 
-# END IFBUILT
-# IFUNBUILT
-# use Code::Embeddable; *pick = \&Code::Embeddable::pick;
-# END IFUNBUILT
-
-
 my $term_width;
 if (defined $ENV{COLUMNS}) {
     $term_width = $ENV{COLUMNS};
@@ -204,6 +199,13 @@ sub hr_app {
     [200, "OK", $res];
 }
 
+sub hr_r {
+    my $res = hr_app(random_color=>1, random_pattern=>1);
+    my $hr  = $res->[2];
+    return $hr if defined(wantarray);
+    print $hr;
+}
+
 1;
 # ABSTRACT: Print horizontal bar on the terminal
 
@@ -219,31 +221,33 @@ App::hr - Print horizontal bar on the terminal
 
 =head1 VERSION
 
-This document describes version 0.24 of App::hr (from Perl distribution App-hr), released on 2015-12-28.
+This document describes version 0.25 of App::hr (from Perl distribution App-hr), released on 2016-06-17.
 
 =head1 SYNOPSIS
 
- use App::hr qw(hr);
+ use App::hr qw(hr hr_r);
  hr;
 
 Sample output:
 
  =============================================================================
 
+Set pattern:
+
  hr('x----');
 
 Sample output:
 
  x----x----x----x----x----x----x----x----x----x----x----x----x----x----x----x-
 
+Use random color and random pattern:
+
+ hr_r;
+
 You can also use the provided CLI L<hr>.
 
 =for Pod::Coverage ^(pick)$
 
-=head1 SEE ALSO
-
-L<ruler> (L<App::ruler>)
-
 =head1 FUNCTIONS
 
 =head2 hr([ PATTERN [, COLOR ] ]) => optional STR
@@ -259,6 +263,10 @@ defautl is C<=>.
 Under Windows, will shave one character at the end because the terminal cursor
 will move a line down when printing at the last column.
 
+=head2 hr_r => optional STR
+
+Like C<hr>, but will set random pattern and random color.
+
 
 =head2 hr_app(%args) -> [status, msg, result, meta]
 
@@ -304,7 +312,7 @@ Usage:
 
 If you use Perl, you can also use the C<hr> function in C<App::hr> module.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -353,7 +361,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-hr>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-SHARYANTO-Term-Util>.
+Source repository is at L<https://github.com/perlancar/perl-App-hr>.
 
 =head1 BUGS
 
@@ -363,13 +371,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<ruler> (L<App::ruler>)
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
